package com.qizhen.healsphere.common.excel;


import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.qizhen.healsphere.common.ai.BaidubceUtil;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.*;
import java.util.stream.Collectors;

public class ExcelProcess {
    public static void haoyiwang() {
        String urlExcelPath = "C:\\Users\\17664\\Desktop\\好医网项目\\dz_disease_vs_dwh_content.xlsx"; // 包含URL的Excel文件路径
        String diseaseExcelPath = "C:\\Users\\17664\\Desktop\\好医网项目\\咋诊数据\\dz_disease_info.xlsx"; // 包含疾病名称、ID和关键词的Excel文件路径

        // 读取疾病名称、ID和关键词，并存储在HashMap中
        Map<String, List<String>> diseaseInfoMap = new HashMap<>();
        try (InputStream diseaseInputStream = new FileInputStream(diseaseExcelPath)) {
            Workbook diseaseWorkbook = new XSSFWorkbook(diseaseInputStream);
            Sheet diseaseSheet = diseaseWorkbook.getSheetAt(0);
            for (Row row : diseaseSheet) {
                Cell nameCell = row.getCell(1); // 假设疾病名称在第一列
                Cell idCell = row.getCell(0); // 假设疾病ID在第二列
                Cell keywordsCell = row.getCell(37); // 假设疾病关键词在第三列
                if (nameCell != null && idCell != null && keywordsCell != null) {
                    String diseaseName = nameCell.getStringCellValue().trim();
                    //String diseaseId = idCell.getStringCellValue().trim();
                    String keywords = keywordsCell.getStringCellValue().trim();
                    List<String> infoList = new ArrayList<>();
                    //infoList.add(diseaseId);
                    infoList.add(diseaseName);
                    if (!keywords.isEmpty()) {
                        infoList.addAll(Arrays.asList(keywords.split(",")));
                    }
                    diseaseInfoMap.put(diseaseName, infoList);
                }
            }
            diseaseWorkbook.close();
        } catch (IOException e) {
            e.printStackTrace();
        }

        // 读取URL并检查文章内容
        try (InputStream urlInputStream = new FileInputStream(urlExcelPath)) {
            Workbook urlWorkbook = new XSSFWorkbook(urlInputStream);
            Sheet urlSheet = urlWorkbook.getSheetAt(0);

            // 创建新列来存储包含的疾病名称和ID
            int diseasesNameColumnIndex = urlSheet.getRow(0).getLastCellNum() + 1;
            int diseasesIdColumnIndex = diseasesNameColumnIndex + 1;
            urlSheet.getRow(0).createCell(diseasesNameColumnIndex).setCellValue("Disease Names");
            urlSheet.getRow(0).createCell(diseasesIdColumnIndex).setCellValue("Disease IDs");

//            ExecutorService executorService = Executors.newFixedThreadPool(THREAD_COUNT);
            for (int rowNum = 1; rowNum <= urlSheet.getLastRowNum(); rowNum++) {
                Row row = urlSheet.getRow(rowNum);
                Cell urlCell = row.getCell(3); // 假设URL在第一列
                if (urlCell != null) {
                    System.out.println("现在是北京时间：" + DateUtil.format(DateUtil.date(), DatePattern.ISO8601_PATTERN) + ",当前处理第" + urlCell.getRowIndex() + "行");
                    String urlString = urlCell.getStringCellValue();
                    processUrl(urlString, diseaseInfoMap, urlSheet, rowNum, diseasesNameColumnIndex, diseasesIdColumnIndex);
                }
            }

            // 将更新后的Excel文件写回到磁盘
            try (OutputStream outputStream = new FileOutputStream("F:\\武汉好医网_文章匹配疾病\\匹配好之后的文件1.xlsx")) {
                urlWorkbook.write(outputStream);
            }
            urlWorkbook.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private static void processUrl(String urlString, Map<String, List<String>> diseaseInfoMap, Sheet urlSheet, int rowNum, int diseasesNameColumnIndex, int diseasesIdColumnIndex) {
        StringBuilder diseasesNamesBuilder = new StringBuilder();
        StringBuilder diseasesIdsBuilder = new StringBuilder();

        try {
            URL url = new URL(urlString);
            HttpURLConnection connection = (HttpURLConnection) url.openConnection();
            connection.setRequestMethod("GET");
            connection.connect();

            int responseCode = connection.getResponseCode();
            if (responseCode != HttpURLConnection.HTTP_OK) {
                System.out.println("Failed to fetch the URL: HTTP error code: " + responseCode + ", url is: " + urlString);
                return;
            }

            BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
            String line;
            StringBuilder content = new StringBuilder();

            while ((line = reader.readLine()) != null) {
                content.append(line);
            }
            reader.close();

            // 检查是否包含疾病名称或关键词
//            boolean matched = false;
            for (Map.Entry<String, List<String>> entry : diseaseInfoMap.entrySet()) {
                String diseaseName = entry.getKey();
                List<String> infoList = entry.getValue();
                if (!infoList.isEmpty()) {
                    String diseaseId = infoList.get(0);
                    Set<String> collect = infoList.stream().skip(1).collect(Collectors.toSet());
//                    infoList.remove(0);
                    for (String term : collect) {
                        if (content.toString().contains(term)) {
                            if (diseasesNamesBuilder.length() > 0) diseasesNamesBuilder.append(", ");
                            diseasesNamesBuilder.append(diseaseName);
                            if (diseasesIdsBuilder.length() > 0) diseasesIdsBuilder.append(", ");
                            diseasesIdsBuilder.append(diseaseId);
                            break;
                        }
                    }
                }

            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        // 将结果写入Excel
        Row row = urlSheet.getRow(rowNum);
        Cell diseasesNameCell = row.createCell(diseasesNameColumnIndex);
        diseasesNameCell.setCellValue(diseasesNamesBuilder.toString());
        Cell diseasesIdCell = row.createCell(diseasesIdColumnIndex);
        diseasesIdCell.setCellValue(diseasesIdsBuilder.toString());
    }

    public static void icd10() {
        String accessToken = BaidubceUtil.getAccessToken();
        String jsonstr = "{\"dept_list\":[{\"dept_name\":\"皮肤\",\"dept_name_cms\":\"皮肤科\",\"diseases\":[{\"disease_name\":\"湿疹\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"痤疮\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"足癣/脚气\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"脱发\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"银屑病/牛皮癣\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"特应性皮炎/AD\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"甲真菌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"带状疱疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"梅毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"获得性免疫缺陷综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"白癜风\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"毛囊炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扁平疣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"汗疱疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脂肪瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲沟炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"过敏性紫癜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"生殖器疱疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脂溢性皮炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴虱\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"玫瑰糠疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"花斑癣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"股癣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"淋球菌感染\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经性皮炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"珍珠状阴茎丘疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"日光性皮炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肛门瘙痒症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"丘疹性荨麻疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"臭汗症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"丹毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"系统性红斑狼疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"疥疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鹅口疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"斑秃\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"疖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"玫瑰痤疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性荨麻疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黑色素瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆碱能性荨麻疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尖锐湿疣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性荨麻疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"接触性皮炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肋间神经痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"麻疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黄褐斑\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"毛囊角化病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"传染性软疣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"白化病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黑棘皮病\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"心血管\",\"dept_name_cms\":\"心血管科\",\"diseases\":[{\"disease_name\":\"高血压\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"冠心病\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"房颤\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"心力衰竭\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"低血压\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心肌缺血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心肌炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心绞痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"窦性心动过缓\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性心肌梗死\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高脂血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺栓塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺动脉高压\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"动脉粥样硬化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"窦性心动过速\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵圆孔未闭\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"预激综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心包积液\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扩张型心肌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"室上性心动过速\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"室间隔缺损\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺水肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高同型半胱氨酸血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"动脉导管未闭\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性冠脉综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肥厚型心肌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺源性心脏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"房室传导阻滞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高血压危象\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"二尖瓣关闭不全\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"病态窦房结综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"主动脉瓣关闭不全\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"二尖瓣狭窄\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高血压性心脏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"室性心动过速\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"二尖瓣脱垂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心包炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"早期复极综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"主动脉瓣狭窄\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性肺源性心脏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"静脉血栓栓塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心脏肥大\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"主动脉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心内膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心源性水肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心室颤动\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血脂异常\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"应激性心肌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"主动脉夹层\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心源性晕厥\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"肿瘤\",\"dept_name_cms\":\"肿瘤科\",\"diseases\":[{\"disease_name\":\"乳腺癌\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"肝癌\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"宫颈癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结直肠癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"前列腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胰腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"食管癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻咽癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"畸胎瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黑色素瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口腔癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫内膜癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睾丸癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑膜瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"膀胱癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"喉癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸腺瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鳞状细胞癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴茎癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆管癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性粒细胞白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"错构瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆囊癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"软骨瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"外阴癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胶质母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"横纹肌肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脂肪肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"淋巴管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尤因肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"髓母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肛门癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴道癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腺样囊性癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"垂体腺瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卡波西肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸膜间皮瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"印戒细胞癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胰腺神经内分泌肿瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"星形细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"平滑肌肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫平滑肌瘤\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"内分泌\",\"dept_name_cms\":\"内分泌\",\"diseases\":[{\"disease_name\":\"痛风\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"糖尿病\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"甲状腺功能亢进\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多囊卵巢综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺功能减退\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"桥本甲状腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高尿酸血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胰岛素抵抗\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"低钾血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"妊娠期糖尿病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"低钙血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"性早熟\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"亚急性甲状腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"糖尿病酮症酸中毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"电解质紊乱\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"糖尿病足\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"库欣综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿崩症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"嗜铬细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨质疏松症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"苯丙酮尿症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"1型糖尿病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"糖尿病肾病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高泌乳素血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"侏儒症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"痛风性关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺危象\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"原发性醛固酮增多症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高钙血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状旁腺功能亢进\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高胰岛素血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肥胖症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"代谢综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"代谢性碱中毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"新生儿低血糖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾上腺皮质功能减退症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颅咽管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"男子乳房发育\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肢端肥大症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"POEMS综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾上腺增生\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状腺腺瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多毛症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"低镁血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状旁腺功能减退症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"巨人症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳酸性酸中毒\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"运动骨骼\",\"dept_name_cms\":\"骨科\",\"diseases\":[{\"disease_name\":\"腰椎间盘突出症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"强直性脊柱炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腱鞘炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"坐骨神经痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"滑膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"半月板损伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肋软骨炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腱鞘囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"坏死性筋膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扁平足\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腕管综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"梨状肌综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨刺\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脊柱侧凸\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"拇外翻\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"生长痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨性关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肋骨骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨肉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨质疏松症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肌筋膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"马方综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肌腱炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨髓炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"歌舞伎综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肱骨外上髁炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肌肉拉伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脊髓空洞症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腘窝囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颈椎间盘突出\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"椎管狭窄\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"软骨瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"韧带损伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"股骨颈骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"滑囊炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脊髓损伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"跟腱断裂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨筋膜室综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"隐性脊柱裂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"粉碎性骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肌肉痉挛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"关节积液\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骶髂关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"创伤性关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尺神经损伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"桡神经损伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肘外翻\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肩关节脱位\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"呼吸\",\"dept_name_cms\":\"呼吸科\",\"diseases\":[{\"disease_name\":\"哮喘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性支气管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"新型冠状病毒肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性阻塞性肺疾病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"气胸\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结核病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺栓塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺动脉高压\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"过敏性咳嗽\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"气管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"咳嗽变异性哮喘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"支原体肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尘肺病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸腺瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"流行性感冒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸腔积液\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"百日咳\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结节病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"呼吸性碱中毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性支气管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结核性胸膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"呼吸衰竭\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺水肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"支气管扩张症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺源性心脏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺脓肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睡眠呼吸暂停综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"矽肺\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"吸入性肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性呼吸窘迫综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"间质性肺病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"病毒性肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"机化性肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"人感染禽流感\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"放射性肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳糜胸\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"细菌性肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸膜间皮瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心源性哮喘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"韦格纳肉芽肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺泡蛋白沉积症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"特发性肺纤维化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"衣原体肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"淋巴管肌瘤病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺曲菌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"隐球菌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"呼吸性酸中毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺吸虫病\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"眼部\",\"dept_name_cms\":\"眼科\",\"diseases\":[{\"disease_name\":\"白内障\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"青光眼\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"麦粒肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"飞蚊症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"散光\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"角膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"干燥性角结膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"近视\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"弱视\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"玻璃体混浊\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"霰粒肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"沙眼\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"斜视\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"色盲\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"圆锥角膜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"倒睫\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"眼结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"远视\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"翼状胬肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"葡萄膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"夜盲症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"虹膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"霍纳综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"泪囊炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视神经萎缩\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"太田痣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视神经炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"玻璃体后脱离\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视网膜脱离\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黄斑病变\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睑缘炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"上睑下垂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视网膜母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"巩膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睑裂斑\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"屈光参差\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"复视\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"眼球震颤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睑板腺功能障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"缺血性视神经病变\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"虹膜睫状体炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"角膜溃疡\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视盘水肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视网膜静脉阻塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"中心性浆液性脉络膜视网膜病变\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"玻璃体积血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视网膜动脉阻塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视网膜变性\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睑内翻\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"神经\",\"dept_name_cms\":\"神经科\",\"diseases\":[{\"disease_name\":\"阿尔茨海默病\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"脑梗死\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"癫痫\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"失眠\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"偏头痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"帕金森病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑出血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"三叉神经痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"重症肌无力\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"格林-巴利综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑震荡\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腔隙性脑梗死\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睡眠障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"烟雾病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"不安腿综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝性脑病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑膜瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"特发性震颤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"呃逆\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"梅尼埃病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经纤维瘤病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"面肌痉挛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多发性硬化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多发性硬化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"斜视\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"前庭神经炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经胶质瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"短暂性脑缺血发作\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"运动神经元病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脊髓炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高同型半胱氨酸血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肌萎缩侧索硬化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"海绵状血管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血管性头痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"发作性睡病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多系统萎缩\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"丛集性头痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"进行性肌营养不良\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颅内动脉瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑水肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胶质母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视神经萎缩\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"莱姆病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"韦尼克脑病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"紧张型头痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"视神经炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"舞蹈症\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"妇产\",\"dept_name_cms\":\"妇产科\",\"diseases\":[{\"disease_name\":\"宫颈癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多囊卵巢综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴道炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿路感染\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫平滑肌瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"盆腔炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"异位妊娠\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"宫颈炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿道炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"宫颈囊肿\",\"is_zhuanqu\":\"\"},{\"disease_name\":\"宫颈息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫内膜异位症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"细菌性阴道病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫脱垂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫内膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫腺肌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"假性湿疣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢早衰\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫内膜息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"外阴炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫粘连\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"巴氏腺囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫内膜癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"宫颈腺囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"输卵管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"外阴湿疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黄体囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"输卵管积液\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"功能失调性子宫出血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"附件囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"外阴癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢过度刺激综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴道松弛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴道囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"外阴囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"绒毛膜癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"压力性尿失禁\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢发育不良\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"习惯性流产\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"处女膜闭锁\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"前庭大腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴道癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"瘢痕子宫\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"盆腔粘连\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"子宫肥大\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵巢囊肿蒂扭转\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多毛症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"经前期综合征\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"消化\",\"dept_name_cms\":\"消化科\",\"diseases\":[{\"disease_name\":\"肝癌\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"胃癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乙型肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"便秘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肠炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆囊炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃溃疡\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胰腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝硬化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆囊息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胰腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腹泻\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肠易激综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝血管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"克罗恩病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"食管癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"十二指肠溃疡\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃食管反流病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃出血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"溃疡性结肠炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"食管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"丙型肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃下垂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"直肠炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝性脑病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃穿孔\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝内胆管结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"呃逆\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"食管裂孔疝\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"自身免疫性肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆管癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"蛔虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳糖不耐受\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝衰竭\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆囊癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"酒精性脂肪肝\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"非酒精性脂肪性肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"布加综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"功能性消化不良\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝纤维化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝脓肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"Barrett食管\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脾功能亢进\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"原发性胆汁性胆管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲型肝炎\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"耳鼻喉\",\"dept_name_cms\":\"耳鼻喉科\",\"diseases\":[{\"disease_name\":\"中耳炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"耳石症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腺样体肥大\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻窦炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扁桃体炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性咽炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"过敏性鼻炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻咽癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"晕动病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻中隔偏曲\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼓膜穿孔\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"喉癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"梅尼埃病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"喉炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻甲肥大\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"声带息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"前庭神经炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"感音神经性聋\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"会厌囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻咽炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"耵聍栓塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性鼻炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睡眠呼吸暂停综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"萎缩性鼻炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性会厌炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻后滴漏综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"听神经瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"空鼻症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"喉息肉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲状舌管囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑脊液鼻漏\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳突炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扁桃体恶性肿瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻前庭炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"软喉症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼻骨骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胆脂瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"咽鼓管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"咽鼓管阻塞\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"咽鼓管异常开放症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"耳硬化症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扁桃体周围脓肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"小耳畸形\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"喉乳头状瘤\",\"is_zhuanqu\":\"\"},{\"disease_name\":\"迷路炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颈静脉球瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"先天性耳聋\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"招风耳\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"传导性聋\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"口腔\",\"dept_name_cms\":\"口腔科\",\"diseases\":[{\"disease_name\":\"口腔溃疡\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙周炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙髓炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鹅口疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙龈炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"磨牙症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"智齿冠周炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"唇炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口腔癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"干槽症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙龈萎缩\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"龋病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"复发性阿弗他溃疡\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阻生齿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"根尖周炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口角炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"地图舌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口腔扁平苔藓\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"唇腭裂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"氟斑牙\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"唇裂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"错牙合畸形\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"舌炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"釉质发育不全\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙龈瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颞下颌关节病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口腔黏膜白斑\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腭裂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"额外牙\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口腔念珠菌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"成釉细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颌骨囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙髓坏死\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙龈囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳牙滞留\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"唇癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"毛状白斑\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"口腔黏膜下纤维化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙本质敏感症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黏液囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"涎腺囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"下颌骨骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"牙齿磨损\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"日光性唇炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颧骨骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"唾液腺结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"颞骨骨折\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"上颌骨骨折\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"精神心理\",\"dept_name_cms\":\"心理精神科\",\"diseases\":[{\"disease_name\":\"焦虑症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"失眠\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"精神分裂症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"孤独症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"双相障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经官能症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"社交恐惧症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"斯德哥尔摩综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"分离性障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"抑郁障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睡眠障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"注意缺陷多动障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"创伤后应激障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"强迫症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"嗜睡症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"广场恐怖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"偏执型人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"边缘型人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"惊恐障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"被害妄想症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"反社会型人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"表演型人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"幽闭恐惧症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"戒断反应\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"拖延症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"回避型人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"疑病症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"人格解体\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"妄想性障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"心境障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"解离症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"产后抑郁症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恐高症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恐惧症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"自恋型人格障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"暴食症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"梦游症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恋童障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恋物癖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"躯体形式障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"惊恐发作\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经性厌食\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"咬甲癖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"健忘症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脸盲症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"抽动障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"异食癖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"露阴癖\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"分裂样人格障碍\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"泌尿\",\"dept_name_cms\":\"泌尿科\",\"diseases\":[{\"disease_name\":\"前列腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿路感染\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"精索静脉曲张\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"早泄\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"包皮龟头炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿道炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"珍珠状阴茎丘疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"包皮过长\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"膀胱炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿道结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"勃起功能障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿道下裂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"包茎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性前列腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"附睾炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睾丸炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鞘膜积液\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"精囊炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"输尿管结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾盂肾炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睾丸癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"膀胱癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"嗜铬细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴茎癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睾丸扭转\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿潴留\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾错构瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴茎短小\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"膀胱结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"无精症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿失禁\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"膀胱过度活动症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"包皮嵌顿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"性功能障碍\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"克氏综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阴囊炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"前列腺结石\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"佩罗尼病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"遗尿症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾结核\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾上腺皮质功能减退症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"男性不育症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"软下疳\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"马尾综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"马蹄形肾\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"睾丸萎缩\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"尿道肉阜\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"儿科\",\"dept_name_cms\":\"儿科\",\"diseases\":[{\"disease_name\":\"疱疹性咽峡炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"手足口病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腺样体肥大\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"水痘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"扁桃体炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"幼儿急疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"川崎病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"地中海贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腮腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"新生儿黄疸\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"唐氏综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鹅口疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"畸胎瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"抽动症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"包茎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"佝偻病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"非特异性肠系膜淋巴结炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"猩红热\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鞘膜积液\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"低钙血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"性早熟\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"烟雾病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卵圆孔未闭\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"新生儿肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"婴儿湿疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"漏斗胸\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鸡胸\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"生长痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"先天性心脏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"喉炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肠套叠\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"苯丙酮尿症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脊髓灰质炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"蛔虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"1型糖尿病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"马方综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"蛛网膜囊肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨髓炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"神经母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"坏血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"糖尿病肾病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性肾小球肾炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"法洛四联症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"锌缺乏症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性上呼吸道感染\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脐疝\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"侏儒症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"单核细胞增多症\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"感染\",\"dept_name_cms\":\"感染科\",\"diseases\":[{\"disease_name\":\"新型冠状病毒肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"疱疹性咽峡炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"手足口病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"获得性免疫缺陷综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺结核\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乙型肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肠炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"破伤风\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"水痘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"狂犬病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"腮腺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脑膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结核病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"布氏杆菌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"EB病毒感染\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"疟疾\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脓毒症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"猩红热\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"丙型肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"麻疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"真菌感染\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"风疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"鼠疫\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"支原体肺炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"伤寒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"天花\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"传染性单核细胞增多症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恙虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"霍乱\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"登革热\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"蛔虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"出血热\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"弓形虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结核性胸膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"麻风病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血吸虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"猫抓病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肠结核\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"流行性乙型脑炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"戊型肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"蛲虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结核性脑膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"白喉\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"莱姆病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"丝虫病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肾结核\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"炭疽\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"甲型肝炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结核性腹膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"病毒性肺炎\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"风湿免疫\",\"dept_name_cms\":\"风湿免疫科\",\"diseases\":[{\"disease_name\":\"痛风\",\"is_zhuanqu\":\"1\"},{\"disease_name\":\"强直性脊柱炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"过敏性紫癜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"类风湿关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高尿酸血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"系统性红斑狼疮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"干燥综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"皮肌炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"硬皮病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结节性红斑\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"白塞氏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"痛风性关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"狼疮性肾炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"成人斯蒂尔病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"抗磷脂抗体综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骶髂关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多发性肌炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"纤维肌痛综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"反应性关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"银屑病性关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"未分化结缔组织病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"POEMS综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"ANCA相关性血管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"风湿性多肌痛\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"IgG4相关性疾病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脊柱关节炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"韦格纳肉芽肿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"风湿热\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"混合性结缔组织病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卡斯钦-贝克病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血清病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"过敏性血管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"巨细胞动脉炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"抗合成酶抗体综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"复发性多软骨炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"硬肿症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"结节性多动脉炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"冷球蛋白血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"红斑性肢痛症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"小舞蹈病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"嗜酸性筋膜炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"重叠综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"掌腱膜挛缩症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"X连锁无丙种球蛋白血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"费尔蒂综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"近端指间关节周围胶原沉积症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肥大性骨关节病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"显微镜下多血管炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"Erdheim-Chester病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"浆细胞增多症\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"血液\",\"dept_name_cms\":\"血液科\",\"diseases\":[{\"disease_name\":\"白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"地中海贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"再生障碍性贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"缺铁性贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血友病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨髓增生异常综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"噬血细胞综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性淋巴细胞白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血小板减少性紫癜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"溶血性贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性粒细胞白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"中性粒细胞减少症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性髓系白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"葡萄糖-6-磷酸脱氢酶缺乏症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"非霍奇金淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"弥散性血管内凝血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"霍奇金淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"卟啉病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"弥漫性大B细胞淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"真性红细胞增多症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血小板增多症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"骨髓纤维化\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性淋巴细胞白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"原发性血小板增多症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"脾功能亢进\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"急性早幼粒细胞白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"POEMS综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"滤泡性淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血栓性血小板减少性紫癜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"易栓症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恶性贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"黑热病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"自身免疫性溶血性贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"伯基特淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"套细胞淋巴瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"阵发性睡眠性血红蛋白尿症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"浆细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"类白血病反应\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"遗传性球形红细胞增多症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"老年性紫癜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"叶酸缺乏症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"慢性肉芽肿病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"毛细胞白血病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"上肢深静脉血栓形成\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"铁粒幼细胞贫血\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"暴发性紫癜\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"冷球蛋白血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恶性组织细胞病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肝素诱导性血小板减少症\",\"is_zhuanqu\":\"0\"}]},{\"dept_name\":\"其他\",\"dept_name_cms\":\"其他科\",\"diseases\":[{\"disease_name\":\"食物中毒\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"跟腱炎\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"瘢痕疙瘩\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"烫伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"汗管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳头内陷\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"色素痣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"念珠菌病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"增生性瘢痕\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"副乳\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"休克\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"毛细血管瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"维生素A缺乏病\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"药疹\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肺隔离症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"烧伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胃泌素瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"膈疝\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"高磷血症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"皮内痣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸腺癌\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"小儿脑性瘫痪\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"糖原累积症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"内眦赘皮\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"闭锁综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"皮下脂肪瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"巨大胎儿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"肌腱损伤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"上腔静脉综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"胸廓出口综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"贫血痣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"毛细血管扩张症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"淋巴管瘘（淋巴瘘）\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"蓝痣\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳房发育不良\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"恶病质\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"血管脂肪瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"气管食管瘘\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"维生素B12缺乏症\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多器官功能障碍综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"戒酒综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"维生素B2缺乏\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"乳房下垂\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"食管憩室\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"多指畸形\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"短肠综合征\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"炎性肌纤维母细胞瘤\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"食管狭窄\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"连体婴儿\",\"is_zhuanqu\":\"0\"},{\"disease_name\":\"电烧伤\",\"is_zhuanqu\":\"0\"}]}]}";
        JSONObject json = JSON.parseObject(jsonstr);
        JSONArray deptList = json.getJSONArray("dept_list");
        // 创建一个新的Excel工作簿
        Workbook workbook = new XSSFWorkbook();
        BaidubceUtil baidubceUtil = new BaidubceUtil();
        for (int i = 0; i < deptList.size(); i++) {
            if(i == 1) {
                break;
            }
            // 创建一个工作表sheet
            JSONObject jsonObject = deptList.getJSONObject(i);
            Sheet sheet = workbook.createSheet(jsonObject.get("dept_name_cms").toString());
            // 自动调整列宽
            sheet.autoSizeColumn(0);
            JSONArray diseases = jsonObject.getJSONArray("diseases");
            for (int j = 0; j < diseases.size(); j++) {
                if(j == 6) {
                    break;
                }
                String diseaseName = diseases.getJSONObject(j).getString("disease_name");
                // 创建行和单元格
                Row row = sheet.createRow(j); // 行索引从0开始
                Cell cell0 = row.createCell(0); // 列索引从0开始
                // 设置单元格的值
                cell0.setCellValue(diseaseName);
                String chatResponse = baidubceUtil.getChatResponse(diseaseName + "对应的ICD-10疾病名称和编码是什么？输出格式请使用json方式，使其一一对应，多值请用数组形式, json需要具备可读的格式。不需要输出json之外的其他内容",accessToken);
                Cell cell1 = row.createCell(1);
                cell1.setCellValue(chatResponse);
            }

        }
        // 将工作簿写入文件
        try (FileOutputStream fileOut = new FileOutputStream("E:\\disease.xlsx")) {
            workbook.write(fileOut);
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                workbook.close(); // 关闭工作簿释放资源
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    public static void main(String[] args) {
        //icd10();
        haoyiwang();
    }
}
