package com.qizhen.healsphere.facade;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qizhen.healsphere.repository.mapper.entity.PresetInfo;
import com.qizhen.healsphere.common.enums.IsDeleteEnum;
import com.qizhen.healsphere.common.exception.CommonErrorCode;
import com.qizhen.healsphere.common.exception.CommonException;
import com.qizhen.healsphere.service.impl.KgServiceImpl;
import com.qizhen.healsphere.web.dto.*;
import com.qizhen.healsphere.web.param.KgQuery;
import com.qizhen.healsphere.web.param.KgTree;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 用户日志业务层
 * @author: gaodm
 * @time: 2018/8/6 9:11
 */
@Component
public class KgFacade extends KgServiceImpl {
    @Autowired
    private PresetInfoFacade presetInfoFacade;

    public GraphLabelDTO getGraphFac(KgQuery kgQuery) {
        GraphLabelDTO graphLabelDTO = new GraphLabelDTO();
        List<CategorieDTO> categories = new ArrayList<>();
        List<GNodeDTO> node = new ArrayList<>();
        List<LinkDTO> links = new ArrayList<>();
        List<GraphDTO> res = this.getGraph(kgQuery);
        if (CollUtil.isEmpty(res)) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS);
        } else {
            Integer nodeId = 0;
            categories.add(new CategorieDTO("中心词"));
            categories.add(new CategorieDTO("关系"));
            Map<String, Integer> cMap = new HashMap<>();
            cMap.put("中心词", 0);
            cMap.put("关系", 1);

            GraphDTO graphDTO = res.get(0);
            GNodeDTO gNodeDTO
                    = new GNodeDTO(graphDTO.getLabel(), 0, graphDTO.getName(), nodeId, "circle", 50);
            nodeId++;
            node.add(gNodeDTO);
            if (CollUtil.isNotEmpty(graphDTO.getENodeRSDTOS())) {
                Integer rsId = 2;
                for (BaseNodeRSDTO baseNodeRSDTO : graphDTO.getENodeRSDTOS()) {
                    if (null == cMap.get(baseNodeRSDTO.getRType())) {
                        cMap.put(baseNodeRSDTO.getRType(), rsId);
                        categories.add(new CategorieDTO(baseNodeRSDTO.getRType()));
                        rsId++;
                    }
                    GNodeDTO nNodeDTO
                            = new GNodeDTO("", 1, "", nodeId, "diamond", 10);
                    node.add(nNodeDTO);
                    links.add(new LinkDTO(gNodeDTO.getName(), nNodeDTO.getName(), baseNodeRSDTO.getRType()));
                    nodeId++;
                    if (CollUtil.isNotEmpty(baseNodeRSDTO.getENodeDTOS())) {
                        for (NextNodeDTO baseNodeDTO : baseNodeRSDTO.getENodeDTOS()) {
                            String symbol = "diamond";
                            if (baseNodeDTO.getPCount() > 0) {
                                symbol = "circle";
                            }
                            GNodeDTO eNodeDTO
                                    = new GNodeDTO(baseNodeDTO.getLabel(), cMap.get(baseNodeRSDTO.getRType()),
                                    baseNodeDTO.getName(), nodeId, symbol, 28);
                            nodeId++;
                            node.add(eNodeDTO);
                            links.add(new LinkDTO(nNodeDTO.getName(), eNodeDTO.getName(), ""));
                        }
                    }
                }
            }
            graphLabelDTO.setCategories(categories);
            graphLabelDTO.setNode(node);
            graphLabelDTO.setLinks(links);
        }

        return graphLabelDTO;
    }

    public TreeDTO getTreeFac(KgTree kgTree) {
        TreeDTO treeDTO = new TreeDTO();
        if ((kgTree.getType() == 1
                && (kgTree.getSubType() == 1 || kgTree.getSubType() == 2 || kgTree.getSubType() == 3))
                || (kgTree.getType() == 2 && (kgTree.getSubType() == 0))
                || (kgTree.getType() == 3 && (kgTree.getSubType() == 0))
                || (kgTree.getType() == 4 && (kgTree.getSubType() == 0))
                || (kgTree.getType() == 5 && (kgTree.getSubType() == 0))
                || (kgTree.getType() == 6 && (kgTree.getSubType() == 0))) {
            // KgQueryVO kgQueryVO = new KgQueryVO();
            // kgQueryVO.setLabelName("诊断依据");
            // kgQueryVO.setInputStr("诊断依据");
            // String tree = this.getTree(kgQueryVO);
            PresetInfo presetInfo = presetInfoFacade.getOne(new QueryWrapper<PresetInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("type", (kgTree.getType() * 10 + kgTree.getSubType())), false);
            String tree = "";
            if (null != presetInfo){
                tree = presetInfo.getContent();
            }
            if (StrUtil.isBlank(tree)) {
                throw new CommonException(CommonErrorCode.NOT_EXISTS);
            } else {
                treeDTO = getTreeDTO(tree);
            }
        } else {
            throw new CommonException(CommonErrorCode.PARAM_IS_ERROR);
        }
        return treeDTO;
    }

    private TreeDTO getTreeDTO(String tree) {
        TreeDTO treeDTO = new TreeDTO();
        List<TreeNodeDTO> nodes = new ArrayList<>();
        Tree treeObj = JSONUtil.toBean(tree, Tree.class);
        if (null != treeObj) {
            Map<String, Integer> treeMap = new HashMap<>();
            treeMap.put("根节点", 0);
            addTree(nodes, treeObj, treeMap, "根节点");
        }

        treeDTO.setNodes(nodes);
        return treeDTO;
    }

    private void addTree(List<TreeNodeDTO> nodes, Tree treeObj, Map<String, Integer> treeMap, String pName) {
        if (null == treeMap.get(treeObj.getName())) {
            treeMap.put(treeObj.getName(), treeMap.size());
        }

        TreeNodeDTO node = new TreeNodeDTO("/images/icon.png",
                "/images/iconOpen.png",
                "/images/iconClose.png",
                treeMap.get(treeObj.getName()), treeObj.getName(), treeMap.get(pName));
        nodes.add(node);
        if (CollUtil.isNotEmpty(treeObj.getSNode())) {
            for (Tree tree : treeObj.getSNode()) {
                addTree(nodes, tree, treeMap, treeObj.getName());
            }
        } else {
            node.setIcon("/images/node.png");
            node.setIconOpen("");
            node.setIconClose("");
        }
    }

}
