package com.qizhen.healsphere.repository.neo4j;

import org.neo4j.driver.types.Node;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.neo4j.core.Neo4jClient;
import org.springframework.stereotype.Repository;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

@Repository
public class BasePropertyRepository {

    @Autowired
    private Neo4jClient neo4jClient;

    public BasePropertyRepository(Neo4jClient neo4jClient) {
        this.neo4jClient = neo4jClient;
    }

    public Map<String,Object> createProperty(String label, Long nodeId, Map<String, Object> properties) {
        StringBuilder setClause = new StringBuilder();
        properties.forEach((key, value) -> setClause.append("n.").append(key).append(" = $").append(key).append(", "));

        // 移除最后的逗号
        if (setClause.length() > 0) {
            setClause.setLength(setClause.length() - 2);
        }

        String query = String.format("MATCH (n:`%s`) WHERE id(n) = $nodeId SET %s RETURN n", label, setClause);

        Optional<Map> optionalMap = neo4jClient.query(query)
                .bindAll(properties)
                .bind(nodeId).to("nodeId")
                .fetchAs(Map.class)
                .mappedBy((typeSystem, record) -> {
                    Node node = record.get("n").asNode();

                    Map<String, Object> result = new HashMap<>();
                    result.put("id", node.id());
                    result.put("labels", node.labels()); // 获取节点的标签
                    result.put("properties", node.asMap()); // 获取节点的属性

                    return result;
                }).one();
        return (Map<String, Object>) optionalMap.orElse(null);
    }

    public Map<String,Object> deleteProperty(String label, Long nodeId,String propertyName) {
        String query = String.format("MATCH (n:`%s`) WHERE id(n) = $nodeId REMOVE n.%s RETURN n", label,propertyName);

        Optional<Map> optionalMap = neo4jClient.query(query)
                .bind(nodeId).to("nodeId")
//                .bind(propertyName).to("propertyName")
                .fetchAs(Map.class)
                .mappedBy((typeSystem, record) -> {
                    Node node = record.get("n").asNode();

                    Map<String, Object> result = new HashMap<>();
                    result.put("id", node.id());
                    result.put("labels", node.labels()); // 获取节点的标签
                    result.put("properties", node.asMap()); // 获取节点的属性

                    return result;
                }).one();
        return (Map<String, Object>) optionalMap.orElse(null);
    }

    public Map<String,Object> updateProperty(String label,Long nodeId,String oldPropertyName,String newPropertyName,String newPropertyValue) {
        String query = String.format("MATCH (n:`%s`) WHERE id(n) = $nodeId REMOVE n.%s " +
                "SET n.%s = $newPropertyValue RETURN n", label,oldPropertyName,newPropertyName);
        Optional<Map> optionalMap = neo4jClient.query(query)
                .bind(nodeId).to("nodeId")
//                .bind(oldPropertyName).to("oldPropertyName")
//                .bind(newPropertyName).to("newPropertyName")
                .bind(newPropertyValue).to("newPropertyValue")
                .fetchAs(Map.class)
                .mappedBy((typeSystem, record) -> {
                    Node node = record.get("n").asNode();

                    Map<String, Object> result = new HashMap<>();
                    result.put("id", node.id());
                    result.put("labels", node.labels()); // 获取节点的标签
                    result.put("properties", node.asMap()); // 获取节点的属性

                    return result;
                }).one();
        return (Map<String, Object>) optionalMap.orElse(null);

    }
}