package com.qizhen.healsphere.repository.neo4j;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.neo4j.core.Neo4jClient;
import org.springframework.stereotype.Repository;

import java.util.*;

@Repository
public class BaseRelationshipRepository {

    @Autowired
    private Neo4jClient neo4jClient;

    public BaseRelationshipRepository(Neo4jClient neo4jClient) {
        this.neo4jClient = neo4jClient;
    }

    public void createRelationship(String startLabel, Long startId, String endLabel, Long endId, String relationshipType, Map<String, Object> properties) {
        StringBuilder setClause = new StringBuilder();
        properties.forEach((key, value) -> setClause.append("r.").append(key).append(" = $").append(key).append(", "));

        if (setClause.length() > 0) {
            setClause.setLength(setClause.length() - 2);
        }

        String query = String.format(
                "MATCH (a:`%s`), (b:`%s`) WHERE id(a) = $startId AND id(b) = $endId " +
                        "CREATE (a)-[r:`%s`]->(b) " +
                        "SET %s RETURN r",
                startLabel, endLabel, relationshipType, setClause
        );

        neo4jClient.query(query)
                .bind(startId).to("startId")
                .bind(endId).to("endId")
                .bindAll(properties)
                .run();
    }

    public void updateRelationship(String oldRelationshipType, String newRelationshipType) {

        String query = String.format(
                "MATCH (a)-[r:`%s`]->(b) " +
                        "CREATE (a)-[new_r:`%s`]->(b) " +
                        "SET new_r += r " +
                        "DELETE r",
                oldRelationshipType, newRelationshipType
        );

        neo4jClient.query(query)
                .run();
    }

    public List<String> findRelationshipNames(String name) {

        String query = "match ()-[r]-() where type(r) contains $name return distinct type(r)";

        Collection<String> collection = neo4jClient.query(query)
                .bind(name).to("name")
                .fetchAs(String.class)
                .all();
        if (collection.isEmpty()) {
            return Collections.emptyList();
        }
        return new ArrayList<>(collection);
    }



    public void deleteRelationship(String startLabel, Long startId, String endLabel, Long endId, String relationshipType) {
        String query = String.format(
                "MATCH (a:`%s`)-[r:`%s`]->(b:`%s`) WHERE id(a) = $startId AND id(b) = $endId DELETE r",
                startLabel, relationshipType, endLabel
        );

        neo4jClient.query(query)
                .bind(startId).to("startId")
                .bind(endId).to("endId")
                .run();
    }
}