package com.qizhen.healsphere.web;

import com.qizhen.healsphere.web.dto.GraphLabelDTO;
import com.qizhen.healsphere.web.dto.RespDTO;
import com.qizhen.healsphere.web.dto.TreeDTO;
import com.qizhen.healsphere.facade.KgFacade;
import com.qizhen.healsphere.web.param.KgQuery;
import com.qizhen.healsphere.web.param.KgTree;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * @Description: 朗通知识图谱控制层
 * @author: gaodm
 * @time: 2018/8/30 10:12
 */
@Controller
@RequestMapping("/kg")
@Api(value = "朗通知识图谱API", tags = { "朗通知识图谱API" })
@SuppressWarnings("unchecked")
@Slf4j
public class KgController {
    private static final String KGTREECACHE = "KgTreeCache";

    @Autowired
    private KgFacade kgFacade;

    @ApiOperation(value = "获取图谱", notes = "获取图谱")
    @RequestMapping(value = "/getGraph", method = RequestMethod.POST)
    @ResponseBody
    public RespDTO<GraphLabelDTO> getGraph(@RequestBody @Valid KgQuery kgQuery) {
        return RespDTO.onSuc(kgFacade.getGraphFac(kgQuery));
    }

    @ApiOperation(value = "获取树形分类",
            notes = "获取树形分类(疾病ICD10：t：1，st：1)<br>" +
                    "(疾病科室：t：1，st：2)<br>" +
                    "(药品：t：2，st：0)<br>" +
                    "(症状：t：3，st：0)<br>" +
                    "(手术和操作：t：4，st：0)<br>" +
                    "(实验室检查：t：5，st：0)<br>" +
                    "(辅助检查：t：6，st：0)<br>")
    @RequestMapping(value = "/getTree", method = RequestMethod.POST)
    @ResponseBody
    @Cacheable(value = KGTREECACHE, key = "'kgtree:t_' + #kgTree.type + '_st_' + #kgTree.subType")
    public RespDTO<TreeDTO> getTree(@RequestBody @Valid KgTree kgTree) {
        log.info("获取树形分类缓存成功");
        return RespDTO.onSuc(kgFacade.getTreeFac(kgTree));
    }
}

